magneticalc.CheckForUpdates_Dialog.CheckForUpdates_Dialog

# ``magneticalc`.`CheckForUpdates_Dialog`.`CheckForUpdates_Dialog``

class documentation

`class CheckForUpdates_Dialog(QDialog2):`

Constructor: `CheckForUpdates_Dialog()`

View In Hierarchy

CheckForUpdates_Dialog class.

Static Method | `parse_contents` | Extracts and parses the version number from the raw Version.py contents.
Static Method | `remote_contents` | Gets the contents of a remote file.
Method | `__init__` | Initializes the dialog.
Method | `check_for_updates` | Checks for updates.

Inherited from `QDialog2`:

Method | `show` | Shows this dialog.
Method | `showEvent` | Gets called when the dialog is opened.
Instance Variable | `user_accepted` | Undocumented

Inherited from `QLayouted` (via `QDialog2`):

Method | `addButtons` | Adds buttons.
Method | `addLayout` | Adds layout.
Method | `addSpacing` | Adds spacing.
Method | `addWidget` | Adds widget.
Method | `install_layout` | Installs this layout in the parent.
Instance Variable | `_layout` | Undocumented

@staticmethod
def parse_contents(contents: `str`) -> `str | None`:

Extracts and parses the version number from the raw Version.py contents.

Parameters
contents: `str` | Contents

Returns
`str | None` | Version string if successful, None otherwise

@staticmethod
def remote_contents(url: `str`, timeout: `int`) -> `str | None`:

Gets the contents of a remote file.

Parameters
url: `str` | URL
timeout: `int` | Timeout (s)

Returns
`str | None` | Contents if successful, None otherwise

def __init__(self):
overrides `magneticalc.QtWidgets2.QDialog2.QDialog2.__init__`

Initializes the dialog.

def check_for_updates(self) -> `tuple[str, str, bool, bool]`:

Checks for updates.

Returns
`tuple[str, str, bool, bool]` | Icon, text, success flag, error flag